@@ -49,7 +49,7 @@ class HttpApiGenerator(object):
         domain=None,
         fail_on_warnings=False,
         description=None,
-        disable_execute_api_endpoint=False,
+        disable_execute_api_endpoint=None,
     ):
         """Constructs an API Generator class that generates API Gateway resources
 
@@ -109,8 +109,8 @@ class HttpApiGenerator(object):
         if self.fail_on_warnings:
             http_api.FailOnWarnings = self.fail_on_warnings
 
-        if self.disable_execute_api_endpoint:
-            http_api.DisableExecuteApiEndpoint = self.disable_execute_api_endpoint
+        if self.disable_execute_api_endpoint is not None:
+            self._add_endpoint_configuration()
 
         if self.definition_uri:
             http_api.BodyS3Location = self._construct_body_s3_dict()
@@ -129,6 +129,32 @@ class HttpApiGenerator(object):
 
         return http_api
 
+    def _add_endpoint_configuration(self):
+        """Add disableExecuteApiEndpoint if it is set in SAM
+        HttpApi doesn't have vpcEndpointIds
+
+        Note:
+        DisableExecuteApiEndpoint as a property of AWS::ApiGatewayV2::Api needs both DefinitionBody and
+        DefinitionUri to be None. However, if neither DefinitionUri nor DefinitionBody are specified,
+        SAM will generate a openapi definition body based on template configuration.
+        https://docs.aws.amazon.com/serverless-application-model/latest/developerguide/sam-resource-api.html#sam-api-definitionbody
+        For this reason, we always put DisableExecuteApiEndpoint into openapi object.
+
+        """
+        if self.disable_execute_api_endpoint and not self.definition_body:
+            raise InvalidResourceException(
+                self.logical_id, "DisableExecuteApiEndpoint works only within 'DefinitionBody' property."
+            )
+        editor = OpenApiEditor(self.definition_body)
+
+        # if DisableExecuteApiEndpoint is set in both definition_body and as a property,
+        # SAM merges and overrides the disableExecuteApiEndpoint in definition_body with headers of
+        # "x-amazon-apigateway-endpoint-configuration"
+        editor.add_endpoint_config(self.disable_execute_api_endpoint)
+
+        # Assign the OpenApi back to template
+        self.definition_body = editor.openapi
+
     def _add_cors(self):
         """
         Add CORS configuration if CORSConfiguration property is set in SAM.
@@ -314,11 +340,16 @@ class HttpApiGenerator(object):
                 invalid_regex = r"[^0-9a-zA-Z\/\-\_]+"
                 if re.search(invalid_regex, path) is not None:
                     raise InvalidResourceException(self.logical_id, "Invalid Basepath name provided.")
-                # ignore leading and trailing `/` in the path name
-                m = re.search(r"[a-zA-Z0-9]+[\-\_]?[a-zA-Z0-9]+", path)
-                path = m.string[m.start(0) : m.end(0)]
-                if path is None:
-                    raise InvalidResourceException(self.logical_id, "Invalid Basepath name provided.")
+
+                if path == "/":
+                    path = ""
+                else:
+                    # ignore leading and trailing `/` in the path name
+                    m = re.search(r"[a-zA-Z0-9]+[\-\_]?[a-zA-Z0-9]+", path)
+                    path = m.string[m.start(0) : m.end(0)]
+                    if path is None:
+                        raise InvalidResourceException(self.logical_id, "Invalid Basepath name provided.")
+
                 logical_id = "{}{}{}".format(self.logical_id, re.sub(r"[\-\_]+", "", path), "ApiMapping")
                 basepath_mapping = ApiGatewayV2ApiMapping(logical_id, attributes=self.passthrough_resource_attributes)
                 basepath_mapping.DomainName = ref(self.domain.get("ApiDomainName"))
